@@ -1,4 +1,4 @@
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 # All rights reserved.
 #
 # This source code is licensed under the BSD-style license found in the
@@ -6,23 +6,23 @@
 
 context("session.property")
 
-source('utilities.R')
+source("utilities.R")
 
 query_session_property <- function(conn, property) {
-  properties <- dbGetQuery(conn, 'SHOW SESSION')
-  properties[properties[['Name']] == property, 'Value', drop=TRUE]
+  properties <- dbGetQuery(conn, "SHOW SESSION")
+  properties[properties[["Name"]] == property, "Value", drop = TRUE]
 }
 
 invert_boolean_property <- function(property) {
-  if (property == 'true') 'false' else 'true'
+  if (property == "true") "false" else "true"
 }
 
-test_that('session properties can be configured in connection', {
+test_that("session properties can be configured in connection", {
   conn <- setup_live_connection()
   expect_equal(conn@session$parameters(), list())
 
   # verify default value is applied
-  optimize_hash_generation <- 'optimize_hash_generation'
+  optimize_hash_generation <- "optimize_hash_generation"
   optimize_hash_generation_default <- query_session_property(conn, optimize_hash_generation)
   optimize_hash_generation_inverse <- invert_boolean_property(optimize_hash_generation_default)
 
@@ -36,7 +36,7 @@ test_that('session properties can be configured in connection', {
   conn <- setup_live_connection()
 
   # property can be set via query
-  dbGetQuery(conn, paste0('SET SESSION ', optimize_hash_generation, '=', optimize_hash_generation_inverse))
+  dbGetQuery(conn, paste0("SET SESSION ", optimize_hash_generation, "=", optimize_hash_generation_inverse))
   # property is updated in connection
   expect_equal(conn@session$parameters(), setNames(list(optimize_hash_generation_inverse), optimize_hash_generation))
   # property is reflected in subsequent queries
@@ -44,11 +44,11 @@ test_that('session properties can be configured in connection', {
 
   # additional property can be set
   potential_properties <- c(
-    'columnar_processing',
-    'reorder_joins',
-    'optimize_metadata_queries',
-    'colocated_join',
-    'distributed_join'
+    "columnar_processing",
+    "reorder_joins",
+    "optimize_metadata_queries",
+    "colocated_join",
+    "distributed_join"
   )
   for (additional_property in potential_properties) {
     additional_default <- query_session_property(conn, additional_property)
@@ -57,18 +57,18 @@ test_that('session properties can be configured in connection', {
     }
   }
   if (length(additional_default) == 0) {
-    skip('Cannot find additional property with a default value')
+    skip("Cannot find additional property with a default value")
   }
 
   additional_inverse <- invert_boolean_property(additional_default)
-  dbGetQuery(conn, paste0('SET SESSION ', additional_property, '=', additional_inverse))
+  dbGetQuery(conn, paste0("SET SESSION ", additional_property, "=", additional_inverse))
   # property is set
   expect_equal(query_session_property(conn, additional_property), additional_inverse)
   # previous property is preserved
   expect_equal(query_session_property(conn, optimize_hash_generation), optimize_hash_generation_inverse)
 
   # property can be reset via query
-  dbGetQuery(conn, paste('RESET SESSION', optimize_hash_generation))
+  dbGetQuery(conn, paste("RESET SESSION", optimize_hash_generation))
   # property is cleared in connection and the remaining is preserved
   expect_equal(conn@session$parameters(), setNames(list(additional_inverse), additional_property))
   # property has been reset in subsequent queries
